Struct mmb_parser::index::IndexEntry[][src]

pub struct IndexEntry<'a> {
    pub ptr: u64,
    pub left: u64,
    pub right: u64,
    pub row: u32,
    pub col: u32,
    pub proof: u64,
    pub idx: u32,
    pub kind: u8,
    pub name: &'a [u8],
}

An index entry

Fields

ptr: u64

Pointer to this entry in the index

left: u64

Pointer (file-relative) to the left subtree of this item in the BST

right: u64

Pointer (file-relative) to the right subtree of this item in the BST

row: u32

Row number in source file

col: u32

Column number in source file

proof: u64

Pointer to the command statement that defines this item

idx: u32

Index to the item in the relevant table

kind: u8

To identify the item type

name: &'a [u8]

A null-terminated character string with the name